Example Spec Files
==================

shared

common.yaml
-----------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/common.yaml

teams.yaml
----------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/teams.yaml


----

``awsorgs``


organizational_units.yaml
-------------------------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/organizational_units.yaml


service_control_policies.yaml
-----------------------------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/service_control_policies.yaml


----

``awsaccounts``


accounts.yaml
-------------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/accounts.yaml


----

``awsauth``


users.yaml
----------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/users.yaml

groups.yaml
-----------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/groups.yaml


delegations.yaml
----------------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/delegations.yaml


policy_sets.yaml
----------------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/policy_sets.yaml


custom_policies.yaml
--------------------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/custom_policies.yaml


local_users.yaml
----------------

  .. literalinclude:: ../../awsorgs/spec_init_data/spec.d/local_users.yaml
